@@ -4,7 +4,7 @@
 
 ;; Maintainer: Nicolas P. Rougier <Nicolas.Rougier@inria.fr>
 ;; URL: https://github.com/rougier/nano-theme
-;; Version: 0.3.3
+;; Version: 0.3.4
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: theme, dark, light
 
@@ -94,6 +94,10 @@
 
 ;;; NEWS:
 
+;; Version 0.3.5
+;; - Added diff-hl faces
+;; - Modified line-num er faces
+
 ;; Version 0.3.3
 ;; - Removed debug message
 ;; - Minor changes in agenda
@@ -150,6 +154,10 @@
   "Whether to use font stack"
   :type 'boolean :group 'nano-theme-fonts)
 
+(defcustom nano-window-divider-show nil
+  "Whether to show the vertical window-divider"
+  :type 'boolean :group 'nano-theme)
+
 (defface nano-mono
   '((t (:family "Roboto Mono"
         :height 140
@@ -396,13 +404,13 @@ background color that is barely perceptible."
   (setq blink-cursor-mode nil)
 
   ;; No tooltips
-  (tooltip-mode -1)
+  ;; (tooltip-mode -1)
 
   ;; No scroll bars
-  (scroll-bar-mode -1)
+  ;; (scroll-bar-mode -1)
 
   ;; No toolbar
-  (tool-bar-mode -1)
+  ;; (tool-bar-mode -1)
 
   ;; Default frame settings
   (setq default-frame-alist
@@ -414,6 +422,7 @@ background color that is barely perceptible."
                  '(left-fringe . 0)
                  '(right-fringe . 0)
                  '(undecorated-round . t) ;; emacs-plu@29 only
+                 '(scroll-bar-mode . -1)
                  '(tool-bar-lines . 0)
                  '(menu-bar-lines . 0))))
 
@@ -432,7 +441,7 @@ background color that is barely perceptible."
                           'wrap (make-glyph-code ?- 'nano-faded))
 
   ;; Nerd font for glyph icons
-  (let ((roboto-nerd (font-spec :name "RobotoMono Nerd Font Mono")))
+  (let ((roboto-nerd (font-spec :name "RobotoMono Nerd Font")))
     (if (find-font roboto-nerd)
         (set-fontset-font t '(#xe000 . #xffdd) roboto-nerd)
       (message "Roboto Mono Nerd font has not been found on your system"))))
@@ -455,7 +464,6 @@ background color that is barely perceptible."
 ;;       (push tag properties)))))
 ;;       properties)))
 
-
 (defun nano-new-frame (&optional mode)
   "This funcion creates a new frame in light or dark MODE."
 
@@ -584,6 +592,22 @@ background color that is barely perceptible."
          `(nano-strong ((,light (:weight bold :foreground ,nano-light-strong))
                         (,dark  (:weight bold :foreground ,nano-dark-strong))))))
 
+    ;; --- Window divider ----------------------------------------------
+    (if nano-window-divider-show
+        (custom-theme-set-faces theme
+         `(window-divider ((,light (:foreground ,nano-light-foreground))
+                           (,dark  (:foreground ,nano-dark-foreground))))
+         `(vertical-border ((,light (:foreground ,nano-light-foreground))
+                            (,dark  (:foreground ,nano-dark-foreground)))))
+      (custom-theme-set-faces theme
+       `(window-divider ((,light (:foreground ,nano-light-background))
+                         (,dark  (:foreground ,nano-dark-background))))
+       `(vertical-border ((,light (:foreground ,nano-light-background))
+                          (,dark  (:foreground ,nano-dark-background))))))
+    (custom-theme-set-faces theme
+     '(window-divider-first-pixel ((t (:inherit window-divider))))
+     '(window-divider-last-pixel ((t (:inherit window-divider)))))
+
 
     (custom-theme-set-faces theme
 
@@ -749,14 +773,6 @@ background color that is barely perceptible."
    '(tty-menu-enabled-face         ((t (:inherit nano-default-i))))
    '(tty-menu-selected-face        ((t (:inherit nano-salient-i))))
 
-   ;; --- Windows divider ----------------------------------------------
-   `(window-divider                ((,light (:foreground ,nano-light-background))
-                        (,dark  (:foreground ,nano-dark-background))))
-   '(window-divider-first-pixel    ((t (:inherit window-divider))))
-   '(window-divider-last-pixel     ((t (:inherit window-divider))))
-   `(vertical-border               ((,light (:foreground ,nano-light-background))
-                        (,dark  (:foreground ,nano-dark-background))))
-
    ;; --- Tab bar ------------------------------------------------------
    '(tab-bar                       ((t (:inherit default))))
    '(tab-bar-tab                   ((t (:inherit default))))
@@ -765,10 +781,15 @@ background color that is barely perceptible."
 
    ;; --- Line numbers -------------------------------------------------
    '(line-number                  ((t (:inherit nano-faded))))
-   '(line-number-current-line     ((t (:inherit nil))))
-   `(line-number-major-tick       ((t (:inherit nano-faded))))
+   '(line-number-current-line     ((t (:inherit (nano-strong hl-line)))))
+   `(line-number-major-tick       ((t (:inherit nano-default))))
    '(line-number-minor-tick       ((t (:inherit nano-faded))))
 
+   ;; --- Diff HL (fringe mode) ----------------------------------------
+   '(diff-hl-change                  ((t (:inherit nano-faded-i))))
+   '(diff-hl-insert                  ((t (:inherit nano-salient-i))))
+   '(diff-hl-delete                  ((t (:inherit nano-critical-i))))
+
    ;; --- Font lock ----------------------------------------------------
    '(font-lock-comment-face        ((t (:inherit nano-faded))))
    '(font-lock-doc-face            ((t (:inherit nano-faded))))
@@ -801,22 +822,31 @@ background color that is barely perceptible."
    '(custom-variable-obsolete      ((t (:inherit nano-faded))))
 
    ;; --- Company tooltip ----------------------------------------------
-    '(company-tooltip                      ((t (:inherit nano-subtle))))
-    '(company-tooltip-mouse                ((t (:inherit nano-faded-i))))
-    '(company-tooltip-selection            ((t (:inherit nano-salient-i))))
+   '(company-tooltip                      ((t (:inherit nano-subtle))))
+   '(company-tooltip-mouse                ((t (:inherit nano-faded-i))))
+   '(company-tooltip-selection            ((t (:inherit nano-salient-i))))
 
-    '(company-scrollbar-fg                 ((t (:inherit nano-default-i))))
-    '(company-scrollbar-bg                 ((t (:inherit nano-faded-i))))
+   '(company-scrollbar-fg                 ((t (:inherit nano-default-i))))
+   '(company-scrollbar-bg                 ((t (:inherit nano-faded-i))))
 
-    '(company-tooltip-scrollbar-thumb      ((t (:inherit nano-default-i))))
-    '(company-tooltip-scrollbar-track      ((t (:inherit nano-faded-i))))
+   '(company-tooltip-scrollbar-thumb      ((t (:inherit nano-default-i))))
+   '(company-tooltip-scrollbar-track      ((t (:inherit nano-faded-i))))
 
-    '(company-tooltip-common               ((t (:inherit nano-strong))))
-    '(company-tooltip-common-selection     ((t (:inherit nano-salient-i
+   '(company-tooltip-common               ((t (:inherit nano-strong))))
+   '(company-tooltip-common-selection     ((t (:inherit nano-salient-i
                                                 :weight normal))))
-    '(company-tooltip-annotation           ((t (:inherit nano-default))))
-    '(company-tooltip-annotation-selection ((t (:inherit nano-subtle))))
+   '(company-tooltip-annotation           ((t (:inherit nano-default))))
+   '(company-tooltip-annotation-selection ((t (:inherit nano-subtle))))
 
+   ;; --- Compilation --------------------------------------------------
+   '(compilation-error ((t (:inherit nano-critical))))
+   '(compilation-info ((t (:inherit nano-default))))
+   '(compilation-warning ((t (:inherit nano-popout))))
+   '(compilation-line-number ((t (:inherit nano-default))))
+   '(compilation-column-number ((t (:inherit nano-default))))
+   '(compilation-mode-line-run ((t (:inherit nano-default-i))))
+   '(compilation-mode-line-exit ((t (:inherit nano-default-i))))
+   '(compilation-mode-line-fail ((t (:inherit nano-critical))))
 
    ;; --- Buttons ------------------------------------------------------
    `(custom-button
@@ -874,7 +904,7 @@ background color that is barely perceptible."
    '(helpful-heading                ((t (:inherit nano-strong))))
 
    ;; --- Nano modeline ------------------------------------------------
-   '(nano-modeline-active               ((t (:inherit nano-subtle))))
+;;   '(nano-modeline-active               ((t (:inherit nano-subtle))))
    '(nano-modeline-active-name          ((t (:inherit (nano-strong nano-modeline-active)))))
    '(nano-modeline-active-primary       ((t (:inherit (nano-default nano-modeline-active)))))
    '(nano-modeline-active-secondary     ((t (:inherit (nano-faded nano-modeline-active)))))
@@ -882,7 +912,7 @@ background color that is barely perceptible."
    '(nano-modeline-active-status-RW     ((t (:inherit (nano-faded-i nano-strong)))))
    '(nano-modeline-active-status-**     ((t (:inherit (nano-popout-i nano-strong)))))
 
-   '(nano-modeline-inactive             ((t (:inherit nano-subtle))))
+;;   '(nano-modeline-inactive             ((t (:inherit nano-subtle))))
    '(nano-modeline-inactive-name        ((t (:inherit (nano-faded nano-modeline-inactive)))))
    '(nano-modeline-inactive-primary     ((t (:inherit (nano-faded nano-modeline-inactive)))))
    '(nano-modeline-inactive-secondary   ((t (:inherit (nano-faded nano-modeline-inactive)))))
@@ -940,6 +970,12 @@ background color that is barely perceptible."
    '(diff-refine-changed            ((t (:inherit nano-popout))))
    '(diff-refine-removed            ((t (:inherit nano-faded
                                          :strike-through t))))
+
+   ;; --- icomplete --------------------------------------------------------
+   '(icomplete-first-match          ((t (:inherit nano-strong))))
+   '(icomplete-selected-match       ((t (:inherit nano-strong))))
+   '(icomplete-section              ((t (:inherit nano-strong))))
+
    ;; --- Vertico --------------------------------------------------------
    '(vertico-current                       ((t (:inherit (nano-strong
                                                           nano-subtle)))))
@@ -1004,7 +1040,8 @@ background color that is barely perceptible."
    '(org-agenda-calendar-sexp       ((t (:inherit nano-salient))))
    '(org-agenda-clocking            ((t (:inherit nano-faded))))
    '(org-agenda-column-dateline     ((t (:inherit nano-faded))))
-   '(org-agenda-current-time        ((t (:inherit (nano-strong nano-salient))))
+   '(org-agenda-current-time        ((t (:inherit (nano-strong
+                                                   nano-salient)))))
    '(org-agenda-date                ((t (:inherit nano-strong))))
    '(org-agenda-date-today          ((t (:inherit (nano-salient
                                                    nano-strong)))))
@@ -1100,10 +1137,11 @@ background color that is barely perceptible."
    '(mu4e-footer-face                        ((t (:inherit nano-faded))))
    '(mu4e-forwarded-face                   ((t (:inherit nano-default))))
    '(mu4e-header-face                      ((t (:inherit nano-default))))
-   '(mu4e-header-highlight-face                ((t (:inherit highlight))))
+   '(mu4e-header-highlight-face               ((t (:inherit highlight))))
    '(mu4e-header-key-face                   ((t (:inherit nano-strong))))
    '(mu4e-header-marks-face                  ((t (:inherit nano-faded))))
    '(mu4e-header-title-face                 ((t (:inherit nano-strong))))
+   '(mu4e-header-field-face                 ((t (:inherit nano-strong))))
    '(mu4e-header-value-face                ((t (:inherit nano-default))))
    '(mu4e-highlight-face                    ((t (:inherit nano-popout))))
    '(mu4e-link-face                        ((t (:inherit nano-salient))))
@@ -1283,9 +1321,14 @@ background color that is barely perceptible."
     '(rst-reference                         ((t (:inherit nano-salient))))
     '(rst-transition                        ((t (:inherit nano-default))))
 
-
+    ;; --- Elpher ----------------------------------------------------
+    '(elpher-gemini-heading1                 ((t (:inherit nano-strong))))
+    '(elpher-gemini-heading2                 ((t (:inherit nano-strong))))
+    '(elpher-gemini-heading3                 ((t (:inherit nano-strong))))
+ 
     ;; ---SHR ---------------------------------------------------------
     '(shr-abbreviation                    ((t (:inherit nano-popout))))
+    '(shr-text                            ((t (:inherit nano-default))))
     '(shr-h1                              ((t (:inherit nano-strong))))
     '(shr-h2                              ((t (:inherit nano-strong))))
     '(shr-h3                              ((t (:inherit nano-strong))))
@@ -1380,15 +1423,15 @@ background color that is barely perceptible."
     '(magit-cherry-equivalent                ((t (:inherit nano-default))))
     '(magit-cherry-unmatched                 ((t (:inherit nano-default))))
 
-    '(magit-diff-added                       ((t (:inherit (highlight nano-salient nano-strong)))))
+    '(magit-diff-added                       ((t (:inherit (nano-salient nano-strong)))))
     '(magit-diff-base                        ((t (:inherit nano-default))))
-    '(magit-diff-context                     ((t (:inherit (highlight nano-faded)))))
+    '(magit-diff-context                     ((t (:inherit nano-faded))))
     '(magit-diff-file-heading-selection      ((t (:inherit nano-default))))
     '(magit-diff-hunk-heading-selection      ((t (:inherit nano-default))))
     '(magit-diff-hunk-region                 ((t (:inherit nano-default))))
     '(magit-diff-lines-boundary              ((t (:inherit nano-default))))
     '(magit-diff-our                         ((t (:inherit nano-default))))
-    '(magit-diff-removed                     ((t (:inherit (highlight nano-popout nano-strong)))))
+    '(magit-diff-removed                     ((t (:inherit (nano-popout nano-strong)))))
     '(magit-diff-revision-summary            ((t (:inherit nano-popout))))
     '(magit-diff-their                       ((t (:inherit nano-default))))
     '(magit-diff-whitespace-warning          ((t (:inherit nano-subtle))))
@@ -1403,8 +1446,8 @@ background color that is barely perceptible."
     '(magit-header-line-key                  ((t (:inherit nano-default))))
     '(magit-header-line-log-select           ((t (:inherit nano-default))))
 
-    '(magit-keyword                          ((t (:inherit nano-default))))
-    '(magit-keyword-squash                   ((t (:inherit nano-default))))
+    '(magit-keyword                          ((t (:inherit nano-salient))))
+    '(magit-keyword-squash                   ((t (:inherit nano-salient))))
 
     '(magit-log-author                       ((t (:inherit nano-default))))
     '(magit-log-date                         ((t (:inherit nano-default))))
@@ -1451,7 +1494,10 @@ background color that is barely perceptible."
 
     '(magit-tag                              ((t (:inherit nano-strong))))
 
-
+    ;; --- Transient ------------------------------------------------------
+    ;; Set only faces that influence Magit.  See:
+    ;; <https://github.com/rougier/nano-theme/issues/43>
+    '(transient-value                        ((t (:inherit default))))
 
     ;; --- ANSI colors ----------------------------------------------------
 
